@@ -1,7 +1,3 @@
-import warnings
-
-warnings.filterwarnings("ignore")
-
 import cython
 import pyximport; pyximport.install()
 import pandas as pd
@@ -10,14 +6,15 @@ import xlrd
 import openpyxl
 import PyPDF2
 import glob
-import re
 import os
 import sys
 from io import StringIO
 from math import floor
-import run
-import alac
+from alacorder import run
+from alacorder import alac
+import warnings
 
+warnings.filterwarnings("ignore")
 
 print('''
 
@@ -28,7 +25,7 @@ print('''
 	/_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																														
 		
-		ALACORDER beta 0.6.2
+		ALACORDER beta 6.4
 		by Sam Robson	
 
 
